@@ -38,7 +38,6 @@
 #endif
 
 #include "cc-common-language.h"
-#include "cc-util.h"
 
 #include <glib-object.h>
 
@@ -582,8 +581,10 @@ update_header_func (GtkListBoxRow *child,
 {
         GtkWidget *header;
 
-        if (before == NULL)
+        if (before == NULL) {
+                gtk_list_box_row_set_header (child, NULL);
                 return;
+        }
 
         header = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
         gtk_list_box_row_set_header (child, header);
